# UI utilities for Pythonista (iOS app)

Repository of small UI and other utilities, install with:

    pip install ui3

Included with separate docs:

- anchor - more natural and responsive UI layout creation with anchoring and docking instead of pixel placement
- controllers - wrappers around various iOS built-in dialogs
- [gestures](docs/gestures.md) - Pythonic wrapper around iOS gestures (tap, long press, pinch etc.); includes drag and drop support within and between apps
- gridview - places subviews in grid that is optimized to show as even rectangles as possible
- [menu](docs/menu.md) - wrapper for iOS 14 button pop-up menus
- [richlabel](docs/richlabel.md) - use markup to create fancier labels
- [safearea](docs/safearea.md) - avoids edges (on iPhones)
- scripter - generator-driven UI animations
- [sfsymbol](docs/sfsymbol.md) - use iOS 14 Apple SFSymbols as icon images; includes a browser of all symbols
- [vector](docs/vector.md) - vector class for easier UI calculations
- wkwebview - wrapper for WKWebView, to replace legacy ui.WebView
